@@ -1,13 +1,17 @@
 package App::short;
 
-our $DATE = '2015-03-21'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2015-05-15'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use Log::Any::IfLOG '$log';
 
+# just for testing DZP:Preload
+use constant PRELOAD => $ENV{PRELOAD};
+if (PRELOAD) { require Complete::Util; require Cwd; require File::Spec; require Perinci::Object } # INSERT_PRELOADS: PRELOAD
+
 our %SPEC;
 
 our %common_args = (
@@ -34,8 +38,7 @@ our %detail_l_arg = (
 );
 
 my $_completion_missing = sub {
-    require Complete::Util;
-
+    unless (PRELOAD) { require Complete::Util; } #PRELOAD
     my %args = @_;
     my $word    = $args{word} // '';
     my $cmdline = $args{cmdline};
@@ -61,8 +64,7 @@ my $_completion_missing = sub {
 };
 
 my $_completion_short = sub {
-    require Complete::Util;
-
+    unless (PRELOAD) { require Complete::Util; } #PRELOAD
     my %args = @_;
     my $word    = $args{word} // '';
     my $cmdline = $args{cmdline};
@@ -329,9 +331,8 @@ $SPEC{get_short_target} = {
     },
 };
 sub get_short_target {
-    require Cwd;
-    require File::Spec;
-
+    unless (PRELOAD) { require Cwd; } #PRELOAD
+    unless (PRELOAD) { require File::Spec; } #PRELOAD
     my %args = @_;
     my $res = _validate(\%args);
     return [200,"Invalid input: $res->[0] - $res->[1]"]
@@ -369,9 +370,8 @@ $SPEC{add_short} = {
 };
 sub add_short {
     use experimental 'smartmatch';
-    require Cwd;
-    require File::Spec;
-
+    unless (PRELOAD) { require Cwd; } #PRELOAD
+    unless (PRELOAD) { require File::Spec; } #PRELOAD
     my %args = @_;
     my $res = _validate(\%args);
     return $res unless $res->[0] == 200;
@@ -406,8 +406,7 @@ $SPEC{rm_short} = {
     },
 };
 sub rm_short {
-    require Perinci::Object;
-
+    unless (PRELOAD) { require Perinci::Object; } #PRELOAD
     my %args = @_;
     my $res = _validate(\%args);
     return $res unless $res->[0] == 200;
@@ -446,7 +445,7 @@ App::short - Manage short directory symlinks
 
 =head1 VERSION
 
-This document describes version 0.03 of App::short (from Perl distribution App-short), released on 2015-03-21.
+This document describes version 0.04 of App::short (from Perl distribution App-short), released on 2015-05-15.
 
 =head1 SYNOPSIS
 
